@@ -1,11 +1,11 @@
-package Dancer2::Plugin::Auth::HTTP::Basic::DWIW;
-
 use strict;
 use warnings;
-use Convert::Base64;
-use Dancer2::Plugin;
 
-our $VERSION = '0.0202';
+package Dancer2::Plugin::Auth::HTTP::Basic::DWIW;
+# ABSTRACT: HTTP Basic authentication plugin for Dancer2 that does what I want.
+$Dancer2::Plugin::Auth::HTTP::Basic::DWIW::VERSION = '0.0301';
+use MIME::Base64;
+use Dancer2::Plugin;
 
 our $CHECK_LOGIN_HANDLER = undef;
 
@@ -15,8 +15,6 @@ register http_basic_auth => sub {
     my $realm = plugin_setting->{'realm'} || 'Please login';
 
     return sub {
-        local $@ = undef;
-
         eval {
             my $header = $dsl->app->request->header('Authorization') || die \401;
 
@@ -29,8 +27,6 @@ register http_basic_auth => sub {
             $username || $password || die \401;
 
             if (ref($CHECK_LOGIN_HANDLER) eq 'CODE') {
-                local $@ = undef;
-
                 my $check_result = eval { $CHECK_LOGIN_HANDLER->($username, $password); };
 
                 if($@) {
@@ -76,17 +72,26 @@ register http_basic_auth_set_check_handler => sub {
 
 register_plugin for_versions => [2];
 1;
+
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Dancer2::Plugin::Auth::HTTP::Basic::DWIW - HTTP Basic authentication plugin that does what I want.
+Dancer2::Plugin::Auth::HTTP::Basic::DWIW - HTTP Basic authentication plugin for Dancer2 that does what I want.
 
 =head1 VERSION
 
-Version 0.0202
+version 0.0301
+
+=head1 DESCRIPTION
+
+This plugin gives you the option to use HTTP Basic authentication with Dancer2.
+
+You can set a handler to check the supplied credentials. If you don't set a handler, every username/password combination will work.
 
 =head1 SYNOPSYS
 
@@ -109,12 +114,6 @@ Version 0.0202
     };
     1;
 
-=head1 DESCRIPTION
-
-This plugin gives you the option to use HTTP Basic authentication with Dancer2.
-
-You can set a handler to check the supplied credentials. If you don't set a handler, every username/password combination will work.
-
 =head1 CAUTION
 
 Don't ever use HTTP Basic authentication over clear-text connections! Always use HTTPS!
@@ -193,4 +192,15 @@ CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
 CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+=head1 AUTHOR
+
+Moritz Grosch (LittleFox) <littlefox@fsfe.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Moritz Grosch.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
